ProSHADE: Class Members - Functions

| ProSHADE 0.7.5.4 (MAR 2021) Protein Shape Detection

### - a -

- addExtraSpace() : ProSHADE_internal_data::ProSHADE_data
- addStructure() : ProSHADE_settings
- allocateEMatrices() : ProSHADE_internal_data::ProSHADE_data
- allocateRotatedMap() : ProSHADE_internal_spheres::ProSHADE_sphere
- allocateRotatedSHMemory() : ProSHADE_internal_data::ProSHADE_data
- allocateRRPMemory() : ProSHADE_internal_data::ProSHADE_data
- allocateSO3CoeffsSpace() : ProSHADE_internal_data::ProSHADE_data
- allocateWignerMatricesSpace() : ProSHADE_internal_data::ProSHADE_data
- angularDistanceWithBorders() : ProSHADE_internal_spheres::ProSHADE_rotFun_spherePeakGroup